@@ -48,6 +48,35 @@ class NonSlotted(abc.ABCMeta):
                                                            attributes,
                                                          **kwargs)
 
+class UnhashableMeta(Slotted):
+    
+    """ A slotted metaclass that ensures its classes, and all
+        subclasses, will *not* be hashable types.
+    """
+    
+    def __new__(metacls, name, bases, attributes, **kwargs):
+        """ Override for `abc.ABCMeta.__new__(…)` setting up a
+            derived slotted un-hashable class.
+        """
+        if '__hash__' in attributes:
+            attributes.pop('__hash__')
+        attributes['__hash__'] = None
+        
+        return super(UnhashableMeta, metacls).__new__(metacls, name,
+                                                               bases,
+                                                               attributes,
+                                                             **kwargs)
+
+class Unhashable(abc.ABC, metaclass=UnhashableMeta):
+    
+    @classmethod
+    def __subclasshook__(cls, subcls):
+        if cls is Unhashable:
+            return getattr(subcls, '__hash__', None) is None
+        # elif cls is collections.abc.Hashable:
+        #     return False
+        return NotImplemented
+
 class Format(collections.abc.Callable, metaclass=Slotted):
     
     """ An abstract class representing something that formats something
@@ -179,11 +208,11 @@ class MappingViewRepr(ReprWrapper):
         “self._mapping” value – of which most MappingView types make use.
     """
     
-    def inner_repr(self):
+    def inner_repr(self): # pragma: no cover
         """ Return the repr string for “self._mapping” """
         return repr(self._mapping)
 
-evict_announcer = lambda key, value: print(f"Cache dropped: {key}")
+evict_announcer = lambda key, value: print(f"Cache dropped: {key}") # pragma: no cover
 
 class BaseDescriptor(abc.ABC):
     
@@ -202,7 +231,6 @@ class DataDescriptor(BaseDescriptor):
         ...
     
     def __delete__(self, instance):
-        # raise NotImplementedError("DataDescriptor.__delete__()")
         pass
 
 class NamedDescriptor(DataDescriptor):
@@ -232,7 +260,7 @@ class CacheDescriptor(DataDescriptor, ReprWrapper):
     def __set__(self, instance, value):
         self.lru = value
     
-    def inner_repr(self):
+    def inner_repr(self): # pragma: no cover
         return repr(self.lru)[1:-1]
 
 class Descriptor(NamedDescriptor, SlottedRepr):
@@ -255,7 +283,7 @@ class Descriptor(NamedDescriptor, SlottedRepr):
         if value != self.value:
             raise ValueError("cannot alter {self.name} value")
     
-    def alternative_inner_repr(self):
+    def alternative_inner_repr(self): # pragma: no cover
         from clu.repr import strfield
         value = strfield(self.value)
         return f"name={self.name}, value={value}"
@@ -343,7 +371,7 @@ class ManagedContext(contextlib.AbstractContextManager):
         self.teardown()
         return exc_type is None
 
-if consts.PYTHON_VERSION >= 3.7:
+if consts.PYTHON_VERSION >= 3.7: # pragma: no cover
     
     class AsyncManagedContext(ManagedContext,
                               contextlib.AbstractAsyncContextManager):
@@ -367,6 +395,7 @@ else:
         pass
 
 __all__ = ('Slotted', 'NonSlotted',
+           'UnhashableMeta', 'Unhashable',
            'Format', 'NonFormat', 'SlottedFormat', 'Sanitizer',
            'Cloneable',
            'ReprWrapper', 'SlottedRepr', 'MappingViewRepr',
